@@ -6,7 +6,12 @@
 #' @param toRttm A directory to write RTTM files. If the default \code{toRttm = NULL} is used, \code{'./voiceAudios/rttm'} is created and used.
 #' @param autoDir Logical. Must the directories tree be created? Default: \code{FALSE}. See 'Details'.
 #' @param pycall Python call. See \url{https://github.com/filipezabala/voice} for details.
-#' @param token Access token needed to instantiate pretrained speaker diarization pipeline from pyannote.audio. #1. Visit \url{https://hf.co/pyannote/speaker-diarization} and accept user conditions. #2. Visit \url{https://hf.co/pyannote/segmentation} and accept user conditions. #3. Visit \url{https://hf.co/settings/tokens} to create an access token. More details at \url{https://github.com/pyannote/pyannote-audio}.
+#' @param token Access token needed to instantiate pretrained speaker diarization
+#' pipeline from pyannote.audio. #1 Install pyannote.audio 3.1 with pip install
+#' pyannote.audio (already listed @ https://raw.githubusercontent.com/filipezabala/voice/master/requirements.txt).
+#' #2. Accept \url{https://hf.co/pyannote/segmentation-3.0} user conditions.
+#' #3 Accept \url{https://huggingface.co/pyannote/speaker-diarization-3.1} user conditions.
+#' #4. Create access token.
 #' @return RTTM files in NIST standard. See 'voice::read_rttm'.
 #' @details When \code{autoDir = TRUE}, the following directories are created: \code{'../mp3'},\code{'../rttm'}, \code{'../split'} and \code{'../musicxml'}. Use \code{getwd()} to find the parent directory \code{'../'}.
 #' @import reticulate
@@ -26,7 +31,7 @@
 #' }
 #' @export
 diarize <- function(fromWav, toRttm = NULL, autoDir = FALSE,
-                    pycall = '~/miniconda3/envs/pyvoice38/bin/python3.8',
+                    pycall = '~/miniconda3/envs/pyvoice/bin/python',
                     token = NULL){
 
   if(is.null(token)){
@@ -61,7 +66,7 @@ diarize <- function(fromWav, toRttm = NULL, autoDir = FALSE,
 
   reticulate::use_condaenv(pycall, required = TRUE)
   pyannote <- reticulate::import('pyannote.audio')
-  pipeline <- pyannote$Pipeline$from_pretrained('pyannote/speaker-diarization',
+  pipeline <- pyannote$Pipeline$from_pretrained('pyannote/speaker-diarization-3.1',
                                                 use_auth_token = token)
 
   #TODO: solve 'with closing file handler' issue.
